.. _Postman: https://www.getpostman.com/
.. _Flask: http://flask.pocoo.org/

=============
Flask-Checkr
=============

A tool that allows for quick and extensible JSON Schema validation for a Flask_ application.

